# -*- coding: utf-8 -*-
## GrufSpaces
## Group environments for elaborating and exchanging information
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
__author__  = 'Maik Roeder <maik.roeder@ingeniweb.com>'
__docformat__ = 'restructuredtext'

import unittest
from Products.funittest import logical
from Products.funittest import physical
from Products.funittest import dataprovider
from Products.funittest import precondition
from Products.funittest import TestCase

import os

class TestEmail(TestCase):
    "Email"

    def setUp(self):    
        TestCase.setUp(self)
        # Take all users
        users = dataprovider.cmfplone.user.all()        
        # Make sure they are all existing in Plone
        precondition.cmfplone.user.existing_users(users)
        # Take a groupspace
        self.groupspace = dataprovider.grufspaces.groupspace.get("GroupSpace 1")
        # Add groupspace
        precondition.grufspaces.groupspace.existing_groupspace(self.groupspace)
        # Take all groupspace localroles
        localroles = dataprovider.grufspaces.localroles.all()
        # Populate the groupspace with the groupspace users
        precondition.cmfplone.sharing.having_local_roles(localroles)

    def test_send_mail_to_all_members(self):
        "send a mail to all members"
        # Choose an email to send
        email = dataprovider.grufspaces.groupspaceemails.choice()
        # Send email to all members
        logical.grufspaces.email.send_email_to_all(self.groupspace, email)
     
    def test_send_mail_to_role(self):
        "send a mail to the group"
        # Choose a role
        role=dataprovider.grufspaces.groupspacerole.choice()
        # Choose an email
        email = dataprovider.grufspaces.groupspaceemails.choice()
        # Send email to all members with the role
        logical.grufspaces.email.send_email_to_role(self.groupspace, email, role)

    def test_send_mail_to_member(self):
        "send a mail to the group"
        # Choose a user
        user = dataprovider.grufspaces.groupspaceuser.choice()
        # Choose a mail
        email = dataprovider.grufspaces.groupspaceemails.choice()
        # Send the mail to the user
        logical.grufspaces.email.send_email_to_member(self.groupspace, email, user)

    def test_send_mail_to_group(self):
        "send a mail to group"
        # Choose a group
        group = dataprovider.cmfplone.group.choice()
        # Choose one of the emails to send
        email = dataprovider.grufspaces.groupspaceemails.choice()
        # Send email to the selected group
        logical.grufspaces.email.send_email_to_group(self.groupspace, email, group)
        
if __name__ == "__main__":
    unittest.main()
